Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1561)

Unified Diff: chrome/browser/net/predictor.h

Issue 2038463004: Remove references to network_hints::UrlList and network_hints::NameList (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/net/predictor.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/net/predictor.h
diff --git a/chrome/browser/net/predictor.h b/chrome/browser/net/predictor.h
index cb53b93a7192056a72434b5a51f1b661c9061146..5897d9d3fb9eb8e1823d468fa34e402db1fdbb87 100644
--- a/chrome/browser/net/predictor.h
+++ b/chrome/browser/net/predictor.h
@@ -63,8 +63,6 @@ class PrefRegistrySyncable;
namespace chrome_browser_net {
-typedef network_hints::UrlList UrlList;
-typedef network_hints::NameList NameList;
typedef std::map<GURL, UrlInfo> Results;
// An observer for testing.
@@ -153,7 +151,8 @@ class Predictor {
void PreconnectUrlAndSubresources(const GURL& url,
const GURL& first_party_for_cookies);
- static UrlList GetPredictedUrlListAtStartup(PrefService* user_prefs);
+ static std::vector<GURL> GetPredictedUrlListAtStartup(
+ PrefService* user_prefs);
static void set_max_queueing_delay(int max_queueing_delay_ms);
@@ -176,7 +175,7 @@ class Predictor {
void DiscardAllResults();
// Add hostname(s) to the queue for processing.
- void ResolveList(const UrlList& urls,
+ void ResolveList(const std::vector<GURL>& urls,
UrlInfo::ResolutionMotivation motivation);
void Resolve(const GURL& url, UrlInfo::ResolutionMotivation motivation);
@@ -229,12 +228,12 @@ class Predictor {
void LearnAboutInitialNavigation(const GURL& url);
// Renderer bundles up list and sends to this browser API via IPC.
- // TODO(jar): Use UrlList instead to include port and scheme.
- void DnsPrefetchList(const NameList& hostnames);
+ // TODO(csharrison): Use a GURL vector instead to include port and scheme.
+ void DnsPrefetchList(const std::vector<std::string>& hostnames);
// May be called from either the IO or UI thread and will PostTask
// to the IO thread if necessary.
- void DnsPrefetchMotivatedList(const UrlList& urls,
+ void DnsPrefetchMotivatedList(const std::vector<GURL>& urls,
UrlInfo::ResolutionMotivation motivation);
// May be called from either the IO or UI thread and will PostTask
« no previous file with comments | « no previous file | chrome/browser/net/predictor.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698